@@ -1,5 +1,10 @@
 """Don't have a good day. Have a great day."""
 
+from typing import Final
+
+
+APP_NAME: Final = "greatday"
+
 __author__ = "Bryan M Bugyi"
 __email__ = "bryanbugyi34@gmail.com"
-__version__ = "0.1.0"
+__version__ = "0.2.0"
